package
Version:
v0.0.0-...-db4ded5
Opens a new window with list of versions in this module.
Published: Feb 3, 2021
License: Apache-2.0
Opens a new window with license information.
Imports: 18
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type AuthConfig struct {
AppID string `json:"app_id"`
AppTokenURI string `json:"app_token_uri"`
AppRedirectURI string `json:"app_redirect_uri"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.